@@ -2,11 +2,13 @@ from . import websocket
 
 import sys
 import subprocess
-from colorama import Style, Fore
+from colorama import init, Style, Fore
 
 from distutils import version
 
-__version__ = '0.2.11'
+init()
+
+__version__ = '0.3.3'
 
 try:
     op = subprocess.run([sys.executable, '-m', 'pip', 'install', '--upgrade', 'truedata_ws=='], capture_output=True)
