@@ -6,13 +6,11 @@ import pandas as pd
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
 
-from colorama import Style, Fore, init
+from colorama import Style, Fore
 
 DEFAULT_LIVE_PORT = 8082
 DEFAULT_HIST_PORT = 8092
 
-init()
-
 
 def run_all_tests(username, password, live_port=None, historical_port=None, symbols_to_test=None):
     if live_port is None:
@@ -35,26 +33,27 @@ def run_all_tests(username, password, live_port=None, historical_port=None, symb
 
 
 def get_connection(username, password, live_port_ip, historical_port_ip):
-    td_app = TD(username, password, live_port=live_port_ip, historical_port=historical_port_ip)
-    return td_app
+    td_obj = TD(username, password, live_port=live_port_ip, historical_port=historical_port_ip)
+    return td_obj
 
 
-def run_historical_tests(td_app_ip, symbols):
+def run_historical_tests(td_obj, symbols):
     symbol = symbols[0]
     test_time = datetime.today()
     # Testing malformed historical contracts
-    # hist_data_0 = td_app_ip.get_historic_data(f'BANKNIFTY99ZYXFUT')
+    # hist_data_0 = td_obj.get_historic_data(f'BANKNIFTY99ZYXFUT')
 
     # Testing bar historical data
-    hist_data_1 = td_app_ip.get_historic_data(f'{symbol}')
-    hist_data_2 = td_app_ip.get_historic_data(f'{symbol}', duration='3 D')
-    hist_data_3 = td_app_ip.get_historic_data(f'{symbol}', duration='3 D', bar_size='15 mins')
-    hist_data_4 = td_app_ip.get_historic_data(f'{symbol}', bar_size='30 mins')
-    hist_data_5 = td_app_ip.get_historic_data(f'{symbol}', bar_size='30 mins', start_time=test_time-relativedelta(days=3))
+    hist_data_1 = td_obj.get_historic_data(f'{symbol}')
+    hist_data_2 = td_obj.get_historic_data(f'{symbol}', duration='3 D')
+    hist_data_3 = td_obj.get_historic_data(f'{symbol}', duration='3 D', bar_size='15 mins')
+    hist_data_4 = td_obj.get_historic_data(f'{symbol}', bar_size='30 mins')
+    hist_data_5 = td_obj.get_historic_data(f'{symbol}', bar_size='30 mins', start_time=test_time - relativedelta(days=3))
+    hist_data_6 = td_obj.get_historic_data(f'{symbol}', bar_size='EOD', duration='1 M')
     # Testing tick historical data
-    tick_hist_data_1 = td_app_ip.get_historic_data(f'{symbol}', bar_size='tick')
-    tick_hist_data_2 = td_app_ip.get_historic_data(f'{symbol}', bar_size='tick', duration='3 D')
-    tick_hist_data_3 = td_app_ip.get_historic_data(f'{symbol}', bar_size='tick', start_time=test_time-relativedelta(days=3))
+    tick_hist_data_1 = td_obj.get_historic_data(f'{symbol}', bar_size='tick')
+    tick_hist_data_2 = td_obj.get_historic_data(f'{symbol}', bar_size='tick', duration='3 D')
+    tick_hist_data_3 = td_obj.get_historic_data(f'{symbol}', bar_size='tick', start_time=test_time - relativedelta(days=3))
 
     print(f'{Style.BRIGHT}{Fore.BLUE}------------- HIST BAR DATA TEST RESULTS -------------{Style.RESET_ALL}')
     print()
@@ -76,14 +75,20 @@ def run_historical_tests(td_app_ip, symbols):
     for hist_point in hist_data_3[-20:]:
         print(hist_point)
     print()
-    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 4...)\n"
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 4...\n"
           f"\tCommand used -> hist_data_4 = td_app.get_historic_data('{symbol}', bar_size='30 mins')\n"
           f"\tLENGTH OF RESULT = {len(hist_data_4)}{Style.RESET_ALL}")
     for hist_point in hist_data_4[-20:]:
         print(hist_point)
     print()
     print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 5...\n"
-          f"\tCommand used -> hist_data_5 = td_app.get_historic_data('{symbol}', bar_size='30 mins', start_time={test_time - relativedelta(days=3)})\n"
+          f"\tCommand used -> hist_data_5 = td_app.get_historic_data('{symbol}', bar_size='30 mins', start_time=datetime({(test_time - relativedelta(days=3)).strftime('%Y, %m, %d, %H, %M, %S').replace(' 0', ' ')}))\n"
+          f"\tLENGTH OF RESULT = {len(hist_data_5)}{Style.RESET_ALL}")
+    for hist_point in hist_data_5[-20:]:
+        print(hist_point)
+    print()
+    print(f"{Style.BRIGHT}{Fore.BLUE}HISTDATA 5...\n"
+          f"\tCommand used -> hist_data_6 = td_obj.get_historic_data(f'{symbol}', bar_size='EOD', duration='1 M'))\n"
           f"\tLENGTH OF RESULT = {len(hist_data_5)}{Style.RESET_ALL}")
     for hist_point in hist_data_5[-20:]:
         print(hist_point)
@@ -104,7 +109,7 @@ def run_historical_tests(td_app_ip, symbols):
         print(hist_point)
     print()
     print(f"{Style.BRIGHT}{Fore.BLUE}TICKDATA 3...\n"
-          f"\tCommand used -> tick_data_3 = td_app.get_historic_data('{symbol}', bar_size='tick', start_time={test_time - relativedelta(days=3)})\n"
+          f"\tCommand used -> tick_data_3 = td_app.get_historic_data('{symbol}', bar_size='tick', start_time=datetime({(test_time - relativedelta(days=3)).strftime('%Y, %m, %d, %H, %M, %S').replace(' 0', ' ')}))\n"
           f"\tLENGTH OF RESULT = {len(tick_hist_data_3)}{Style.RESET_ALL}")
     for hist_point in tick_hist_data_3[-20:]:
         print(hist_point)
@@ -120,22 +125,28 @@ def run_historical_tests(td_app_ip, symbols):
     print(df)
 
 
-def run_live_tests(td_app_ip, symbols):
+def run_live_tests(td_obj, symbols):
     # Testing Live data
     # td_app.start_live_data(f'BANKNIFTY{sys.argv[3]}FUTbk')
     print(f'{Style.BRIGHT}{Fore.BLUE}Checking LIVE data streaming...{Style.RESET_ALL}')
-    req_ids = td_app_ip.start_live_data(symbols)
+    req_ids = td_obj.start_live_data(symbols)
     sleep(3)
     print(f"{Style.BRIGHT}{Fore.BLUE}Here's the touchline data...{Style.RESET_ALL}")
     for req_id in req_ids:
-        print(td_app_ip.touchline_data[req_id])
+        print(td_obj.touchline_data[req_id])
     print()
-    print(f"{Style.BRIGHT}{Fore.BLUE}Here's the LIVE stream...{Style.RESET_ALL}")
+    print(f"{Style.BRIGHT}{Fore.BLUE}Here's the LIVE stream... Use Ctrl+C to stop and exit...{Style.RESET_ALL}")
+    sleep(2)  # This is here just to give the user time to read the instructions...
     live_data_objs = {}
     for req_id in req_ids:    
-        live_data_objs[req_id] = deepcopy(td_app_ip.live_data[req_id])
+        live_data_objs[req_id] = deepcopy(td_obj.live_data[req_id])
     while True:
-        for req_id in req_ids:
-            if live_data_objs[req_id] != td_app_ip.live_data[req_id]:
-                print(td_app_ip.live_data[req_id])
-                live_data_objs[req_id] = deepcopy(td_app_ip.live_data[req_id])
+        try:
+            for req_id in req_ids:
+                if live_data_objs[req_id] != td_obj.live_data[req_id]:
+                    print(td_obj.live_data[req_id])
+                    live_data_objs[req_id] = deepcopy(td_obj.live_data[req_id])
+        except KeyboardInterrupt:
+            td_obj.stop_live_data(symbols)
+            td_obj.disconnect()
+            exit()
